package io.hmit.common.utils;

import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import javax.websocket.OnClose;
import javax.websocket.OnMessage;
import javax.websocket.OnOpen;
import javax.websocket.Session;
import javax.websocket.server.PathParam;
import javax.websocket.server.ServerEndpoint;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.CopyOnWriteArraySet;

/**
 * @Description : websocket
 * @Author : Shen Yuanfeng
 * @Date : 2021/5/17 16:31
 */

@Slf4j
@Component
@ServerEndpoint("/webSocket/{orgId}")
public class WebSocket {

    private Session session;

    private static CopyOnWriteArraySet<WebSocket> webSocketSet = new CopyOnWriteArraySet<>();

    private static Map<String, WebSocket> clients = new ConcurrentHashMap<String, WebSocket>();

    private String orgId;

    @OnOpen
    public void opOpen(@PathParam("orgId") String orgId, Session session) {
        this.session = session;
        this.orgId = orgId;
        log.info("【WebSocket】机构上线：{}", orgId);
        clients.put(orgId, this);
        webSocketSet.add(this);
        log.info("【WebSocket】有一个新的连接，总数：{}", webSocketSet.size());
    }

    @OnClose
    public void onClose() {
        webSocketSet.remove(this);
        clients.remove(orgId);
        log.info("【WebSocket】连接断开，总数：{}", webSocketSet.size());

    }

    @OnMessage
    public void onMessage(String message) {
        log.info("【WebSocket】收到客户端发来的消息：{}", message);
    }

    public void sendMessageToOrg(String message, String orgId) {
        message = "您有新的订单：" + message;
        for (WebSocket webSocket : clients.values()) {
            if (webSocket.orgId.equals(orgId) ) {
                webSocket.session.getAsyncRemote().sendText(message);
                break;
            }
        }
    }

    public void sendMessage(String message) {
        for (WebSocket webSocket : webSocketSet) {
            log.info("【WebSocket】广播消息，message={}", message);
            try {
                webSocket.session.getBasicRemote().sendText(message);
            }catch (Exception e) {
//                e.printStackTrace();
            }
        }
    }

}
