package io.hmit.modules.serviceOrder.controller;

import io.hmit.common.annotation.LogOperation;
import io.hmit.common.constant.Constant;
import io.hmit.common.page.PageData;
import io.hmit.common.utils.ExcelUtils;
import io.hmit.common.utils.Result;
import io.hmit.common.validator.AssertUtils;
import io.hmit.common.validator.ValidatorUtils;
import io.hmit.common.validator.group.AddGroup;
import io.hmit.common.validator.group.DefaultGroup;
import io.hmit.common.validator.group.UpdateGroup;
import io.hmit.modules.security.user.SecurityUser;
import io.hmit.modules.serviceOrder.dto.PensionEventDTO;
import io.hmit.modules.serviceOrder.excel.PensionEventExcel;
import io.hmit.modules.serviceOrder.service.PensionEventService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Map;


/**
 * 活动表
 *
 * @author Shen Yuanfeng syf0412@vip.qq.com
 * @since 1.0.0 2021-05-12
 */
@RestController
@RequestMapping("serviceOrder/pensionevent")
@Api(tags="活动表")
public class PensionEventController {
    @Autowired
    private PensionEventService pensionEventService;

    @GetMapping("page")
    @ApiOperation("分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="int") ,
        @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="int") ,
        @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType="String") ,
        @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType="String")
    })
    @RequiresPermissions("serviceOrder:pensionevent:page")
    public Result<PageData<PensionEventDTO>> page(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<PensionEventDTO> page = pensionEventService.page(params);

        return new Result<PageData<PensionEventDTO>>().ok(page);
    }

    @GetMapping("eventByOrg")
    @ApiOperation("本机构活动")
    @ApiImplicitParams({
            @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="int") ,
            @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="int") ,
            @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType="String") ,
            @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType="String"),
            @ApiImplicitParam(name = "orgId", value = "机构Id", paramType = "query", dataType="String")
    })
    @RequiresPermissions("serviceOrder:pensionevent:page")
    public Result<PageData<PensionEventDTO>> eventByOrg(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<PensionEventDTO> page = pensionEventService.getOrgEvent(params);
        return new Result<PageData<PensionEventDTO>>().ok(page);
    }

    @GetMapping("{id}")
    @ApiOperation("信息")
    @RequiresPermissions("serviceOrder:pensionevent:info")
    public Result<PensionEventDTO> get(@PathVariable("id") Long id){
        PensionEventDTO data = pensionEventService.get(id);

        return new Result<PensionEventDTO>().ok(data);
    }

    @PostMapping("updateStatus")
    @ApiOperation("更新活动状态")
    @LogOperation("更新活动状态")
    @RequiresPermissions("serviceOrder:pensionevent:save")
    public Result updateStatus(@RequestParam("eventId") Long id,
                               @RequestParam("status") Integer status,
                               @RequestParam(value = "endDesc", required = false) String endDesc,
                               @RequestParam(value = "eventClock", required = false) String eventClock) {
        pensionEventService.updateStatus(id, status, endDesc, eventClock);
        return new Result();
    }



    @PostMapping
    @ApiOperation("保存")
    @LogOperation("保存")
    @RequiresPermissions("serviceOrder:pensionevent:save")
    public Result save(@RequestBody PensionEventDTO dto){
        //校验数据
        ValidatorUtils.validateEntity(dto, AddGroup.class, DefaultGroup.class);

        pensionEventService.save(dto);

        return new Result();
    }

    @PutMapping
    @ApiOperation("修改")
    @LogOperation("修改")
    @RequiresPermissions("serviceOrder:pensionevent:update")
    public Result update(@RequestBody PensionEventDTO dto){
        //校验数据
        ValidatorUtils.validateEntity(dto, UpdateGroup.class, DefaultGroup.class);

        pensionEventService.update(dto);

        return new Result();
    }

    @DeleteMapping
    @ApiOperation("删除")
    @LogOperation("删除")
    @RequiresPermissions("serviceOrder:pensionevent:delete")
    public Result delete(@RequestBody Long[] ids){
        //校验数据
        AssertUtils.isArrayEmpty(ids, "id");

        pensionEventService.delete(ids);

        return new Result();
    }

    @GetMapping("export")
    @ApiOperation("导出")
    @LogOperation("导出")
    @RequiresPermissions("serviceOrder:pensionevent:export")
    public void export(@ApiIgnore @RequestParam Map<String, Object> params, HttpServletResponse response) throws Exception {
        List<PensionEventDTO> list = pensionEventService.list(params);

        ExcelUtils.exportExcelToTarget(response, null, list, PensionEventExcel.class);
    }

}