package io.hmit.modules.sys.service.impl;

import io.hmit.modules.serviceOrder.dto.PensionOrderDTO;
import io.hmit.modules.sys.service.PushMessage;
import lombok.extern.slf4j.Slf4j;
import me.chanjar.weixin.common.exception.WxErrorException;
import me.chanjar.weixin.mp.api.WxMpService;
import me.chanjar.weixin.mp.bean.template.WxMpTemplateData;
import me.chanjar.weixin.mp.bean.template.WxMpTemplateMessage;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.Arrays;
import java.util.List;

/**
 * @Description : TODO
 * @Author : Shen Yuanfeng
 * @Date : 2021/5/17 13:37
 */

@Slf4j
@Service
public class PushMessageImpl implements PushMessage {

    @Value("${wechat.serviceTemplateId}")
    private String WECHAT_SERVICE_TP;

    @Value("${wechat.userTemplateId}")
    private String WECHAT_USER_TP;

    @Value("${SYSURL.url}")
    private String SYSURL;

    @Autowired
    private WxMpService wxMpService;

    @Override
    public void sendWeChatMsg(PensionOrderDTO pensionOrderDTO, String openId, String flag) {
        WxMpTemplateMessage templateMessage = new WxMpTemplateMessage();
        templateMessage.setTemplateId(WECHAT_USER_TP);
        templateMessage.setToUser(openId);

        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm");
        String appointmentTime = "待分配";
        if (null != pensionOrderDTO.getAppointmentTime()) {
            appointmentTime = sdf.format(pensionOrderDTO.getAppointmentTime());
        }

        List<WxMpTemplateData> data = Arrays.asList(
                new WxMpTemplateData("first", "【智慧养老】您的订单提醒"),
                new WxMpTemplateData("keyword1", pensionOrderDTO.getId().toString()),
                new WxMpTemplateData("keyword2", pensionOrderDTO.getServiceName()),
                new WxMpTemplateData("keyword3", appointmentTime),
                new WxMpTemplateData("remark", "当前状态：" + pensionOrderDTO.getStatusName())
        );
        templateMessage.setData(data);
        String url = SYSURL + "/#/orderDetail/?openid=" + openId + "&id=" + pensionOrderDTO.getId()+"&flag="+flag;
        templateMessage.setUrl(url);
        try{
            wxMpService.getTemplateMsgService().sendTemplateMsg(templateMessage);
        }catch (WxErrorException e){
            log.error("【微信模板消息】发送失败，{}", e);
        }
    }

    @Override
    public void sendServiceWeChatMsg(PensionOrderDTO pensionOrderDTO, String openId) {
        WxMpTemplateMessage templateMessage = new WxMpTemplateMessage();
        templateMessage.setTemplateId(WECHAT_SERVICE_TP);
        templateMessage.setToUser(openId);

        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm");
        String appointmentTime = sdf.format(pensionOrderDTO.getAppointmentTime());

        List<WxMpTemplateData> data = Arrays.asList(
                new WxMpTemplateData("first", "【智慧养老】您的服务单提醒"),
                new WxMpTemplateData("keyword1", pensionOrderDTO.getAppointmentPerson() + " - "+ pensionOrderDTO.getAppointmentPhone()),
                new WxMpTemplateData("keyword2", appointmentTime),
                new WxMpTemplateData("keyword3", pensionOrderDTO.getAddress()),
                new WxMpTemplateData("keyword4", pensionOrderDTO.getServiceName()),
                new WxMpTemplateData("keyword5", pensionOrderDTO.getRemark()),
                new WxMpTemplateData("remark", "当前状态：" + pensionOrderDTO.getStatusName())
        );
        templateMessage.setData(data);
        String url = SYSURL + "/#/orderDetail/?openid=" + openId + "&id=" + pensionOrderDTO.getId()+"&flag=attendant";
        templateMessage.setUrl(url);
        try{
            wxMpService.getTemplateMsgService().sendTemplateMsg(templateMessage);
        }catch (WxErrorException e){
            log.error("【微信模板消息】发送失败，{}", e);
        }
    }
}
