package io.hmit.modules.serviceOrder.controller;

import io.hmit.annotation.Login;
import io.hmit.annotation.LoginUser;
import io.hmit.common.constant.Constant;
import io.hmit.common.page.PageData;
import io.hmit.common.utils.Result;
import io.hmit.common.validator.AssertUtils;
import io.hmit.common.validator.ValidatorUtils;
import io.hmit.common.validator.group.AddGroup;
import io.hmit.common.validator.group.DefaultGroup;
import io.hmit.common.validator.group.UpdateGroup;
import io.hmit.entity.UserEntity;
import io.hmit.modules.serviceOrder.dto.EnrollDTO;
import io.hmit.modules.serviceOrder.service.EnrollService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import java.util.Map;


/**
 * 报名表
 *
 * @author Shen Yuanfeng syf0412@vip.qq.com
 * @since 1.0.0 2021-05-12
 */
@RestController
@RequestMapping("serviceOrder/enroll")
@Api(tags="报名表")
public class EnrollController {
    @Autowired
    private EnrollService enrollService;

    @GetMapping("page")
    @ApiOperation("分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="int") ,
        @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="int") ,
        @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType="String") ,
        @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType="String")
    })
    public Result<PageData<EnrollDTO>> page(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<EnrollDTO> page = enrollService.page(params);

        return new Result<PageData<EnrollDTO>>().ok(page);
    }

    @Login
    @PostMapping("doEnroll")
    @ApiOperation("报名")
    public Result doEnroll(@ApiIgnore @LoginUser UserEntity user,
                           @RequestParam("eventId") Long eventId){
        EnrollDTO enrollDTO = new EnrollDTO();
        enrollDTO.setUserId(user.getId());
        enrollService.addEnrollInfo(enrollDTO, eventId);
        return new Result();
    }


    @GetMapping("{id}")
    @ApiOperation("信息")
    public Result<EnrollDTO> get(@PathVariable("id") Long id){
        EnrollDTO data = enrollService.get(id);

        return new Result<EnrollDTO>().ok(data);
    }

    @PostMapping
    @ApiOperation("保存")
    public Result save(@RequestBody EnrollDTO dto){
        //校验数据
        ValidatorUtils.validateEntity(dto, AddGroup.class, DefaultGroup.class);

        enrollService.save(dto);

        return new Result();
    }

    @PutMapping
    @ApiOperation("修改")
    public Result update(@RequestBody EnrollDTO dto){
        //校验数据
        ValidatorUtils.validateEntity(dto, UpdateGroup.class, DefaultGroup.class);

        enrollService.update(dto);

        return new Result();
    }

    @DeleteMapping
    @ApiOperation("删除")
    public Result delete(@RequestBody Long[] ids){
        //校验数据
        AssertUtils.isArrayEmpty(ids, "id");

        enrollService.delete(ids);

        return new Result();
    }

}